Crate hc_zome_peer_status_coordinator

Crate hc_zome_peer_status_coordinator 

hc_zome_peer_status_coordinator

Coordinator zome to display the online/offline status of agents in a holochain app.

Read about how to include both this zome and its frontend module in your application here.

Enums

SignalPayload

Functions

init
ping
Send a remote signal to the given users to check whether they are online After this ping is sent, a pong is expected as soon as the agents receive the signal
recv_remote_signal